@@ -26,6 +26,7 @@
 #include <CalendarErrors.h>
 #include "cal-home-calendar-util.h"
 
+
 static time_t 
 cal_home_advance_date_by_time_period(struct tm* start,
 				     const CalTimePeriod& ctp)
@@ -336,13 +337,15 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
       cal_home_time_today_midnight(&today_date_today);
 
       gchar* escaped_markedup;
-      if(_todo_is_old(*event_iter, &today_date_today))
+      if((*event_iter)->getType() == E_TODO &&
+	 _todo_is_old(*event_iter, &today_date_today))
       {
 	desktop_plugin->today_events++;
 	escaped_markedup = g_markup_printf_escaped("<span foreground=\"#ff0000\"><b>%s</b></span>", summary.c_str());
       }
       else
 	escaped_markedup = g_markup_printf_escaped("%s", summary.c_str());
+
       summary = string(escaped_markedup);
       g_free(escaped_markedup);
     }
@@ -491,13 +494,189 @@ cal_read_todos_for_calendar(CCalendar* calendar,
   }while(size != 0);
 }
 
+static vector<CComponent*> 
+calendar_getComponents(int calendarId,
+		       int type, int iStDate,
+		       int iEndDate, int iLimit,
+		       int iOffset,
+		       int &error)
+{
+  vector <CComponent *>vListEntry;
+  error = CALENDAR_OPERATION_SUCCESSFUL;
+  
+  CCalendarDB *pDb = CCalendarDB::Instance();
+
+  int iNewStDate = 0;
+  int iNewEndDate = 0;
+  CMulticalendar *mc = CMulticalendar::MCInstance();
+  int time_diff = time_get_time_diff (iStDate, mc->getSystemTimeZone().c_str(), "UTC");
+  iNewStDate = iStDate + time_diff;
+  iNewEndDate = iEndDate + time_diff;
+  
+
+  if (pDb == 0) 
+  {
+    error = CALENDAR_APP_ERROR;
+    return vListEntry;
+  }
+  char *sqlQuery = 
+    sqlite3_mprintf(
+		    "select * from %s where "
+		    "%s = %d  AND  %s = %d AND %s < %d AND %s > %d AND (%s != %d AND %s != %d) "
+		    "union select * from %s where "
+		    "%s = %d AND  %s = %d  AND (%s = 2  OR allday = 1) AND (%s + %s)= %d AND (%s != %d AND %s != %d) " 
+		    "union select * from %s where "
+		    "%s = %d AND %s = %d  AND allday = 0 AND (%s = %d OR %s = %d) AND (%d < %s OR %d = %s) "
+		    "union select * from %s where "
+		    "%s = %d AND %s = %d  AND allday = 1 AND (%s = %d OR %s = %d) AND (%d < (%s + %s) OR %d = %s) "
+		    "LIMIT %d OFFSET %d",
+		    COMPONENTS_TABLE,ENTRY_FIELD_CALID, calendarId,
+		    ENTRY_FIELD_TYPE, type,ENTRY_FIELD_DTSTART, iEndDate,ENTRY_FIELD_DTEND, iStDate,
+		    ENTRY_FIELD_FLAGS, HAS_RECURRENCE,ENTRY_FIELD_FLAGS, HAS_RECURRENCE_ALARM,
+		    
+		    COMPONENTS_TABLE,ENTRY_FIELD_CALID, calendarId, ENTRY_FIELD_TYPE, type, ENTRY_FIELD_TYPE,
+		    ENTRY_FIELD_DTSTART, ENTRY_FIELD_TZOFFSET, iNewStDate,ENTRY_FIELD_FLAGS, 
+		    HAS_RECURRENCE,ENTRY_FIELD_FLAGS, HAS_RECURRENCE_ALARM, 
+		    
+		    COMPONENTS_TABLE,ENTRY_FIELD_CALID, calendarId, ENTRY_FIELD_TYPE, type,
+		    ENTRY_FIELD_FLAGS, HAS_RECURRENCE,ENTRY_FIELD_FLAGS, HAS_RECURRENCE_ALARM,iStDate, 
+		    ENTRY_FIELD_UNTIL,NULLID, ENTRY_FIELD_UNTIL,
+		    
+		    COMPONENTS_TABLE,ENTRY_FIELD_CALID, calendarId,ENTRY_FIELD_TYPE, type, 
+		    ENTRY_FIELD_FLAGS, HAS_RECURRENCE,ENTRY_FIELD_FLAGS, HAS_RECURRENCE_ALARM,
+		    iNewStDate, ENTRY_FIELD_UNTIL, ENTRY_FIELD_TZOFFSET,NULLID, ENTRY_FIELD_UNTIL,
+		    iLimit, iOffset);
+
+  int sqliteError = 0;
+  QueryResult *queryResult = pDb->getRecords(sqlQuery,sqliteError);
+  pDb->sqliteErrorMapper(sqliteError, error);
+  sqlite3_free(sqlQuery);
+
+  if(queryResult == 0) 
+  {
+    if(error == CALENDAR_OPERATION_SUCCESSFUL)
+    {
+      error = CALENDAR_FETCH_NOITEMS;
+    }
+  }
+  else
+  {
+    for(int i = 0; i < queryResult->iRow; i++) 
+    {
+      CComponent *componentEntry = new CComponent();
+      ASSERTION(componentEntry);
+      componentEntry->setCalendarId(calendarId);
+
+      for(int j = 0; j < queryResult->iColumn; j++) 
+      {
+	int k = queryResult->iColumn + (i * queryResult->iColumn);
+
+	if ((queryResult->pResult[k + j]) == 0)
+	  continue;
+
+	switch (j) 
+	{
+	case DB_COLUMN_ID2:
+	  break;
+	case DB_COLUMN_ID1:
+	  componentEntry->setId(queryResult->pResult[k + j]);
+	  break;
+	case DB_COLUMN_ID3:
+	  componentEntry->setType(atoi(queryResult->pResult[k + j]));
+	  break;
+	case DB_COLUMN_ID4:
+	  componentEntry->setFlags(atoi(queryResult->pResult[k + j]));
+	  break;
+	case DB_COLUMN_ID5:
+	  componentEntry->setDateStart(atoi(queryResult->pResult[k + j]));
+	  break;
+	case DB_COLUMN_ID6:
+	  componentEntry-> setDateEnd(atoi(queryResult->pResult[k + j]));
+	  break;
+	case DB_COLUMN_ID7:
+	  if(queryResult->pResult[k + j]) 
+	  {
+	    componentEntry->setSummary((string) queryResult-> pResult[k + j]);
+	  }
+	  break;
+	case DB_COLUMN_ID8:
+	  if(queryResult->pResult[k + j]) 
+	  {
+	    componentEntry->setLocation((string) queryResult->pResult[k + j]);
+	  }
+	  break;
+	case DB_COLUMN_ID9:
+	  if(queryResult->pResult[k + j]) 
+	  {
+	    componentEntry->setDescription((string) queryResult->pResult[k + j]);
+	  }
+	  break;
+	case DB_COLUMN_ID10:
+	  componentEntry->setStatus(atoi(queryResult->pResult[k + j]));
+	  break;
+	case DB_COLUMN_ID11:
+	  if(queryResult->pResult[k + j]) 
+	  {
+	    componentEntry->setGUid(queryResult->pResult[k + j]);
+	  }
+	  break;
+	case DB_COLUMN_ID12:
+	  componentEntry-> setUntil(atoi (queryResult->pResult[k + j]));
+	  break;
+	case DB_COLUMN_ID13:
+	  componentEntry-> setAllDay(atoi (queryResult->pResult[k + j]));
+	  break;
+	case DB_COLUMN_ID14:
+	  componentEntry->setCreatedTime(atoi(queryResult->pResult[k + j]));
+	  break;
+	case DB_COLUMN_ID15:
+	  componentEntry->setLastModified(atoi(queryResult->pResult[k + j]));
+	  break;
+	case DB_COLUMN_ID16:
+	  componentEntry->setTzid(queryResult->pResult[k + j]);
+	  break;
+	default:
+	  break;
+	} 
+      }
+
+      if(componentEntry->getFlags() == HAS_ALARM || componentEntry->getFlags() == HAS_RECURRENCE_ALARM)
+	componentEntry->getAlarmProperties();
+    
+      if(componentEntry->getFlags() == HAS_RECURRENCE || componentEntry->getFlags() == HAS_RECURRENCE_ALARM)
+      {
+	componentEntry->getRecurrenceProperties();
+	if(componentEntry->getInstanceNumber(iStDate, iEndDate)) 
+	{
+	  vListEntry.push_back(componentEntry);
+	}
+	else 
+	{
+	  delete componentEntry;
+	  componentEntry = 0;
+	}
+      }
+      else
+      {
+	vListEntry.push_back(componentEntry);
+      }
+    }
+    if(queryResult) 
+    {
+      sqlite3_free_table(queryResult->pResult);
+      delete queryResult;
+    }
+  }
+  return vListEntry;
+}
+
 static void
-cal_read_ccompnents_for_calendar(CCalendar* calendar,
-				 time_t start_time,
-				 time_t end_time,
-				 SortedCComponentSet& all_components,
-				 gboolean birthday_only,
-				 CalHomePlugin* desktop_plugin)
+cal_read_ccomponents_for_calendar(CCalendar* calendar,
+				  time_t start_time,
+				  time_t end_time,
+				  SortedCComponentSet& all_components,
+				  gboolean birthday_only,
+				  CalHomePlugin* desktop_plugin)
 {
   int error = 0;
   int offset = 0;
@@ -508,41 +687,39 @@ cal_read_ccompnents_for_calendar(CCalendar* calendar,
     int event_type = E_EVENT;
     if(birthday_only)
       event_type = E_BDAY;
+    gchar buf[255];
+    /*
     vector<CComponent*> calendars_components = calendar->getComponents(event_type,
 								       start_time,
 								       end_time,
 								       limit,
 								       offset,
 								       error);
-    /* vector<CComponent*> calendars_components = calendar->getAllEventsTodos(start_time, */
-    /* 									   end_time, */
-    /* 									   limit, */
-    /* 									   offset, */
-    /* 									   error); */
+    */
+
+    vector<CComponent*> calendars_components = calendar_getComponents(calendar->getCalendarId(),
+								      event_type,
+								      start_time, end_time,
+								      limit,
+								      offset,
+								      error);
+
     size = calendars_components.size();
     offset=limit+1;
     limit+=500;
     time_t last_start_date = start_time;
-    time_t system_time_offset = CMulticalendar::MCInstance()->getSystemTimeShift();
     for(int k = 0;k<calendars_components.size();++k)
     {
       CComponent* component = calendars_components[k];
 
       time_t event_time_offset = component->getTzOffset();
-
-      //      vector<time_t> instance_times;
-
       vector<time_t> instance_times =
 	component->getInstanceTimes(last_start_date, 
 				    end_time);
 
-      if((desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_EVENT && calendars_components[k]->getType() == E_TODO) ||
-	 (FALSE==birthday_only && 
-	  ((calendars_components[k]->getType() == E_BDAY) ||
-	   (calendars_components[k]->getType() == E_TODO))) ||
-	 (birthday_only && (calendars_components[k]->getType() == E_EVENT)) ||
-	 (desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_TASK && calendars_components[k]->getType() != E_TODO) ||
-	 (component->getType() == E_TODO && component->getDateStart() > end_time)
+      if((FALSE==birthday_only && (calendars_components[k]->getType() == E_BDAY)) 
+	 ||
+	 (birthday_only && (calendars_components[k]->getType() == E_EVENT))
 	 )
       {
 	delete calendars_components[k];
@@ -600,19 +777,25 @@ cal_read_ccomponents_all_visible(SortedCComponentSet& all_components,
     CCalendar* cal = CMulticalendar::MCInstance()->getCalendarById(desktop_plugin->visible_cals[i], error);
     if(error == 500)
     {
-      cal_read_ccompnents_for_calendar(cal,
-				       start_time,
-				       end_time,
-				       all_components, FALSE,
-				       desktop_plugin);
+      
+      cal_read_ccomponents_for_calendar(cal,
+					start_time,
+					end_time,
+					all_components, FALSE,
+					desktop_plugin);
+      /* cal_read_ccomponents_for_calendar(cal, */
+      /* 					start_time, */
+      /* 					-1, */
+      /* 					all_components, FALSE, */
+      /* 					desktop_plugin); */
       // gnark, birthday events start and end
       // at 00:00:00
 
-      cal_read_ccompnents_for_calendar(cal,
-				       today_midnight_time,
-				       end_time,
-				       all_components, TRUE,
-				       desktop_plugin);
+      cal_read_ccomponents_for_calendar(cal,
+					today_midnight_time,
+					end_time,
+					all_components, TRUE,
+					desktop_plugin);
 
 
       if(desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_TASK ||
