@@ -159,6 +159,8 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
   GtkWidget *launch_view_selector = hildon_touch_selector_new_text();
   GtkWidget *cal_size_selector = hildon_touch_selector_new_text();
   GtkWidget *show_all_recurrence = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  GtkWidget *show_old_undone_tasks = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  GtkWidget *show_done_tasks = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
   GtkWidget* toggle_event_visible = hildon_gtk_radio_button_new(HILDON_SIZE_FINGER_HEIGHT,
 							    NULL);
   GtkWidget* toggle_task_visible = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_FINGER_HEIGHT,
@@ -253,8 +255,17 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
 				 desktop_plugin->show_age);
   hildon_check_button_set_active(HILDON_CHECK_BUTTON(show_all_recurrence), 
 				 desktop_plugin->show_all_recurrences);
+  hildon_check_button_set_active(HILDON_CHECK_BUTTON(show_old_undone_tasks), 
+				 desktop_plugin->show_old_undone_tasks);
+  hildon_check_button_set_active(HILDON_CHECK_BUTTON(show_done_tasks), 
+				 desktop_plugin->show_done_tasks);
+
   gtk_button_set_label(GTK_BUTTON(show_all_recurrence),
 		       "Show all Recurrences");
+  gtk_button_set_label(GTK_BUTTON(show_old_undone_tasks),
+		       "Show old undone tasks");
+  gtk_button_set_label(GTK_BUTTON(show_done_tasks),
+		       "Show done tasks");
 
   gtk_button_set_label(GTK_BUTTON(show_age),
 		       "Show persons age");
@@ -340,6 +351,9 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
   gtk_box_pack_start(GTK_BOX(visible_event_mode_box), toggle_task_visible, TRUE, TRUE, 3);
   gtk_box_pack_start(GTK_BOX(visible_event_mode_box), toggle_event_and_task_visible, TRUE, TRUE, 3);
   gtk_box_pack_start(GTK_BOX(pan_content), visible_event_mode_box, FALSE, FALSE, 3);
+  gtk_box_pack_start(GTK_BOX(pan_content), show_old_undone_tasks, FALSE, FALSE, 3);
+  gtk_box_pack_start(GTK_BOX(pan_content), show_done_tasks, FALSE, FALSE, 3);
+
   hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pan), pan_content);
   gtk_container_add(GTK_CONTAINER(content), pan);
   gtk_widget_show_all(dialog);
@@ -359,6 +373,8 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
     desktop_plugin->show_age = hildon_check_button_get_active(HILDON_CHECK_BUTTON(show_age));
     desktop_plugin->update_if_visible = hildon_check_button_get_active(HILDON_CHECK_BUTTON(update_if_visible));
     desktop_plugin->show_all_recurrences = hildon_check_button_get_active(HILDON_CHECK_BUTTON(show_all_recurrence));
+    desktop_plugin->show_old_undone_tasks = hildon_check_button_get_active(HILDON_CHECK_BUTTON(show_old_undone_tasks));
+    desktop_plugin->show_done_tasks = hildon_check_button_get_active(HILDON_CHECK_BUTTON(show_done_tasks));
     desktop_plugin->show_week_day_name = hildon_check_button_get_active(HILDON_CHECK_BUTTON(show_week_day_name));
     if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle_event_and_task_visible)))
     {
