@@ -657,6 +657,8 @@ cal_home_plugin_init(CalHomePlugin *desktop_plugin)
   desktop_plugin->has_24_time_format = cal_24_time_format();
   desktop_plugin->show_all_recurrences = TRUE;
   desktop_plugin->show_age = FALSE;
+  desktop_plugin->show_old_undone_tasks = TRUE;
+  desktop_plugin->show_done_tasks = TRUE;
   desktop_plugin->visible_entry_mode = VISIBLE_ENTRY_EVENT;
   GtkWidget *contents = build_ui(desktop_plugin);
 
